(function($) {
  "use strict";

  $(document).ready(function() {
    $(".color-picker-4tell").wpColorPicker(); // This creates a wordpress standard color picker

    /*
     * Replace all SVG images with inline SVG
     */
    jQuery("img.svg").each(function() {
      var $img = jQuery(this);
      var imgID = $img.attr("id");
      var imgClass = $img.attr("class");
      var imgURL = $img.attr("src");

      jQuery.get(
        imgURL,
        function(data) {
          // Get the SVG tag, ignore the rest
          var $svg = jQuery(data).find("svg");

          // Add replaced image's ID to the new SVG
          if (typeof imgID !== "undefined") {
            $svg = $svg.attr("id", imgID);
          }
          // Add replaced image's classes to the new SVG
          if (typeof imgClass !== "undefined") {
            $svg = $svg.attr("class", imgClass + " replaced-svg");
          }

          // Remove any invalid XML tags as per http://validator.w3.org
          $svg = $svg.removeAttr("xmlns:a");

          // Check if the viewport is set, if the viewport is not set the SVG wont't scale.
          if (
            !$svg.attr("viewBox") &&
            $svg.attr("height") &&
            $svg.attr("width")
          ) {
            $svg.attr(
              "viewBox",
              "0 0 " + $svg.attr("height") + " " + $svg.attr("width")
            );
          }

          // Replace image with new SVG
          $img.replaceWith($svg);

          var iconBackgroundColor = $(".IconBackgroundColor4T").val();
          var svgFill = $(".IconSvgFillColor4T").val();
          var buttonFontColor = $(".ButtonFontColor4t").val();
          var buttonBorderColor = $(".ButtonBorderColor4t").val();
          var notificationBubbleColor = $(".bubbleBackgroundColor4T").val();
          var trayButtonColor = $(".trayButtonColor4T").val();
          updateIconSvgFill(svgFill);
          updateIconBackgroundColor(iconBackgroundColor);
          updateDefaultTrayFontColor(buttonFontColor);
          updateTrayButtonColor(trayButtonColor);
          updateTrayBorderColor(buttonBorderColor);
          updateNotificationBubbleColor(notificationBubbleColor);
        },
        "xml"
      );
    });

    addOnClickListenersForColorandFontChanges();
    showOrHideOptionsBasedOnIconSelected();
  });

  function addOnClickListenersForColorandFontChanges() {
    updateColorFromColorPicker(".IconSvgFillColor4T", updateIconSvgFill);
    updateColorFromColorPicker(
      ".IconBackgroundColor4T",
      updateIconBackgroundColor
    );
    updateColorFromColorPicker(
      ".ButtonFontColor4t",
      updateDefaultTrayFontColor
    );
    updateColorFromColorPicker(".ButtonBorderColor4t", updateTrayBorderColor);

    updateColorFromColorPicker(
      ".bubbleBackgroundColor4T",
      updateNotificationBubbleColor
    );
    updateColorFromColorPicker(".trayButtonColor4T", updateTrayButtonColor);
  }

  /** Lets only show options to udpate the color, text, and notification bubble color if infact the user selected that option */
  function showOrHideOptionsBasedOnIconSelected() {
    updateMainButtonText(); // call once for when the page loads from the sql table
    $("#ButtonText-4t").on("keyup", updateMainButtonText);

    hideorShowIconOptions(0); // call once for when the page loads from the sql table
    $(".iconSelector4T").on("click", hideorShowIconOptions);

    hideOrShowPromptOptions(0); // call once for when the page loads from the sql table
    $(".PromptLimitedTo4T").change(hideOrShowPromptOptions);

    hideOrShowTrayAutoOpenOptions(0); // call once for when page loads from sql table
    $(".AutoOpenTray4T").change(hideOrShowTrayAutoOpenOptions);
  }

  function hideorShowIconOptions(slideTime) {
    slideTime = slideTime === 0 ? 0 : 300; // poor style, but intended to prevent the initial slideIn on page refresh
    var trayOptions = $(".default-tray-4t-options");
    var iconOptions = $(".icon-4t-options");
    if ($("#default-tray-4t").is(":checked")) {
      trayOptions.slideDown(slideTime);
      iconOptions.hide();
    } else {
      trayOptions.slideUp(slideTime);
      iconOptions.show();
    }
  }

  function hideOrShowTrayAutoOpenOptions(slideTime) {
    slideTime = slideTime === 0 ? 0 : 300; // poor style, but intended to prevent the initial slideIn on page refresh
    if ($(".AutoOpenTray4T-disabled").is(":selected")) {
      $(".AutoOpenTray4T-options").slideUp(slideTime);
    } else {
      $(".AutoOpenTray4T-options").slideDown(slideTime);
    }
  }

  function hideOrShowPromptOptions(slideTime) {
    slideTime = slideTime === 0 ? 0 : 300; // poor style, but intended to prevent the initial slideIn on page refresh
    if ($(".PromptLimitedTo4T-disabled").is(":selected")) {
      $(".PromptOptions-4T").slideUp(slideTime);
    } else {
      $(".PromptOptions-4T").slideDown(slideTime);
    }
  }

  /**
   * wpColorPicker renders a set of divs. Here we grab the hexCode as ther user clicks around the color picker. Then we go and update that somewhere else in the callback
   */
  function updateColorFromColorPicker(selector, callback) {
    $(selector)
      .parents(".wp-picker-container")
      .on("click", function() {
        var colorCode = $(this)
          .find(".color-picker-4tell")
          .val();
        callback(colorCode);
      });
  }

  /** As the user changes the text for the main rectangle display, lets update it in the mock we're making them */
  function updateMainButtonText() {
    var value = $("#ButtonText-4t").val();
    $(".default-tray-placeholder-4t").html(value);
  }

  function updateDefaultTrayFontColor(color) {
    if (color && color.length) {
      $(".default-tray-placeholder-4t").css("color", color);
    }
  }

  function updateTrayBorderColor(color) {
    if (color && color.length) {
      $(".default-tray-placeholder-4t").css("border", "3px solid " + color);
      $(".default-tray-placeholder-4t").css("border-bottom", "0px");
    }
  }

  function updateNotificationBubbleColor(color) {
    if (color && color.length) {
      $(".notificationBubble4T").css("background-color", color);
    }
  }

  function updateTrayButtonColor(color) {
    $(".default-tray-placeholder-4t").css("background-color", color);
    $(".default-tray-placeholder-4t").css("font-size", "14px");
  }

  /** When the color picker changes for the icons, lets update the relevant divs so the user can see what the end experience looks like */
  function updateIconBackgroundColor(color) {
    if (color && color.length) {
      $(".icon-background-4t").css("background-color", color);
    }
  }

  function updateIconSvgFill(color) {
    if (color && color.length) {
      $(".icon-background-4t svg").css("fill", color);
    }
  }
})(jQuery);
